@@ -1,7 +1,10 @@
 #!/usr/bin/env perl
 
 ##################################################################
-# Options.pm 1.5.2
+# Options.pm 1.5
+# 
+# A perl module to provide better support for command-line option
+# parsing, hopefully better than GetOpts.
 # 
 # Copyright (C) 2005-2007 by Phil Christensen
 ##################################################################
@@ -25,66 +28,71 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '1.5.2';
+our $VERSION = '1.5';
 
 =head1 NAME
 
-Options - Yet another Perl module to provide support for command-line option parsing and usage generation.
+Options -   A perl module to provide better support for command-line option
+			parsing, hopefully better than GetOpts.
 
 =head1 SYNOPSIS
 
-    use Options;
-    
-    $options = new Options(params => [
-                                ['port',   'p', undef,       'The port to connect to.'],
-                                ['host',   'h', 'localhost', 'The host to connect to.']
-                           ],
-                           flags =>  [
-                                ['secure', 's', 'Use SSL for encryption.'],
-                                ['quit',   'q', 'Quit after connecting.'],
-                                ['help',   'h', 'Display this usage guide.'],
-                           ]);
-    
-    # Parse the default option source (@ARGV)
-    %results = $options->get_options();
-    
-    # Provide usage
-    if($options->get_result('help')){
-        $options->print_usage();
-        exit(1);
-    }
+	use Options;
+	
+	$options = new Options(params => [
+							['port', 'p', undef, 'The port to connect to.'],
+							['host', 'h', 'localhost', 'The host to connect to.']
+							],
+							flags =>  [
+							['secure', 's', 'Use SSL for encryption.'],
+							['quit', 'q', 'Quit after connecting.'],
+							]);
+	
+	# Parse the default option source (@ARGV)
+	%results = $options->get_options();
+	
+	# Provide usage
+	if($options->get_result('help')){
+		$options->print_usage();
+		exit(1);
+	}
 
 =head1 CONTENTS
 
- Options 1.5.2
+ Options 1.50
 
 =head1 DESCRIPTION
 
-Options was created to somewhat emulate the syntax of the Twisted Python's
-usage library. It provides a parser for command-line options that is integrated
-with an automatic usage generator. Support exists for both flags and parameters,
-in long and short form, required parameters, and default params.
+ Options was created to somewhat emulate the syntax of the Twisted Python's
+ core usage library of the same name. It provides a parser for command-line
+ options that is integrated with an automatic usage generator. Support exists
+ for both flags and parameters, in long and short form, required parameters,
+ and default params.
+
+=head2 EXPORT
+
+None by default.
 
 =head1 GETTING OPTIONS
 
 =over 4
 
-=item * C<< new Options() >>
+=item new Options()
 
-Create a new instance of the Options class. To do so, pass the constructor
-two optional, named arguments. 'params' are command-line switches with
-arguments, while flags are boolean switches. (duh.)
+ Create a new instance of the Options class. To do so, pass the constructor
+ two optional, named arguments. 'params' are command-line switches with
+ arguments, while flags are boolean switches. (duh.)
 
-Each argument consists of an anonymous array reference which contains
-an anonymous array for each option you wish to support.
+ Each argument consists of an anonymous array reference which contains
+ an anonymous array for each option you wish to support.
 
-Params arrays must be four elements long, consisting of the long and short
-versions of the switch, a default value, and a description to be printed in
-the usage guide. If the default value is specified as "undef", it becomes a
-required value, and the program will not continue without it. Options without
-defaults can specify the empty string ("") to omit the default.
+ Params arrays must be four elements long, consisting of the long and short
+ versions of the switch, a default value, and a description to be printed in
+ the usage guide. If the default value is specified as "undef", it becomes a
+ required value, and the program will not continue without it. Options without
+ defaults can specify the empty string ("") to omit the default.
 
-Flags arrays are simpler, and omit the default element.
+ Flags arrays are simpler, and omit the default element.
 
 =back
 
@@ -113,24 +121,22 @@ sub new{
 
 =over 4
 
-=item * C<< $options->get_options() >>
+=item $options->get_options()
 
-This method is called with no arguments, and begins the parsing of
-the global variable C<@ARGV>, or an array passed as the first argument
-to the function. When finished, it returns a hash where the
-keys are the long option names, and the values are the result of the
-parse, i.e., strings for params, and boolean values (1 or 0 actually)
-for flag-type options.
+ This method is called with no arguments, and begins the parsing of
+ the global variable @ARGV, or an array passed as the first argument
+ to the function. When finished, it returns a hash where the
+ keys are the long option names, and the values are the result of the
+ parse, i.e., strings for params, and boolean values (1 or 0 actually)
+ for flag-type options.
 
-If the parser encounters an unknown flag, or a bare word without a
-recognized switch before it, these are left in the C<$options-E<gt>{'unrecognized'}> array in the
-order they are found.
+ If the parser encounters an unknown flag, or a bare word without a
+ recognized switch before it, these are left in the @ARV array in the
+ order they are found, so that a script can do additional processing of
+ @ARGV.
 
-If no array was passed in (i.e., C<@ARGV> was parsed), the unrecognized items
-are left in C<@ARGV> so that a script can do additional processing.
-
-If the result is missing a required parameter, the module prints the
-usage table, and calls C<exit(1)>.
+ If the result is missing a required parameter, the module prints the
+ usage table, and exits with a 1 status code.
 
 =back
 
@@ -142,6 +148,7 @@ sub get_options{
 	unless(@args){
 		@args = @ARGV;
 	}
+	$self->{'last_args'} = \@args;
 	
 	my @unrecognized = ();
 	my %results = ();
@@ -236,24 +243,22 @@ sub get_options{
 	unless(@_){
 		@ARGV = @unrecognized;
 	}
-	
-	$self->{'unrecognized'} = @unrecognized;
 	$self->{'results'} = \%results;
 	return %results;
 }
 
 =over 4
 
-=item * C<< $options->get_result(option) >>
+=item $options->get_result(option)
 
-Although C<get_options()> returns a hash, and that is an
-acceptable way to use the results, this function provides
-some level of convenience when dealing with options that
-may return a reference to a list of results for that option.
-When called in a list context, this will return a list of
-results, even if only one argument was provided.
-However, calling it in a scalar context when there are
-multiple arguments will be, shall we say, disappointing.
+ Although get_options returns a hash, and that is an
+ acceptable way to use the results, this function provides
+ some level of convenience when dealing with options that
+ may return a reference to a list of results for that option.
+ When called in a list context, this will return a list of
+ results, even if only one argument was provided.
+ However, calling it in a scalar context when there are
+ multiple arguments will be, shall we say, disappointing.
 
 =back
 
@@ -274,11 +279,11 @@ sub get_result{
 
 =over 4
 
-=item * C<< $options->print_usage($optional_message) >>
+=item $options->print_usage($optional_message)
 
-Options will automatically display usage information if a required
-parameter is omitted, but this method can be used to implement a
-C<--help> parameter.
+ Options will automatically display usage information if a required
+ parameter is omitted, but this method can be used to implement a
+ --help parameter.
 
 =back
 
@@ -286,16 +291,13 @@ C<--help> parameter.
 sub print_usage{
 	my $self = shift;
 	my $reason = shift;
-	unless(defined($reason)){
-		$reason = '';
-	}
 	
-	my $usage_fh;
-	if($self->{'usage_fh'}){
-		$usage_fh = $self->{'usage_fh'};
+	my $err_handle;
+	if($self->{'err_handle'}){
+		$err_handle = $self->{'err_handle'};
 	}
 	else{
-		$usage_fh = \*STDERR;
+		$err_handle = \*STDERR;
 	}
 	
 	my $app = $self->{'last_args'}[0];
@@ -303,9 +305,9 @@ sub print_usage{
 		$app = $0;
 	}
 	
-	print $usage_fh "$reason\n\n";
-	print $usage_fh "Usage: $app [options]\n";
-	print $usage_fh "Options:\n";
+	print $err_handle "$reason\n\n";
+	print $err_handle "Usage: $app [options]\n";
+	print $err_handle "Options:\n";
 	
 	my $item;
 	my @rows = ();
@@ -337,61 +339,10 @@ sub print_usage{
 	
 	foreach $item (@rows){
 		my @row = @$item;
-		print $usage_fh _pad($row[0], $max_width + 2), $row[1], "\n";
+		print $err_handle _pad($row[0], $max_width + 2), $row[1], "\n";
 	}
 }
 
-=head1 ADVANCED USAGE
-
-Options.pm has a couple of hidden hooks that you may find useful when using
-the module in different ways.
-
-The first allows you to control the default behavior when an error occurs:
-
-    $options->{'exit'} = 0;
-
-When this flag has been set to 0, C<get_options()> will no longer call
-C<exit(1)> after printing the usage when an error occurs. Instead it will
-simply call C<die($reason)>, which you can trap in an C<eval> block.
-
-The second (and more interesting) hook also allows you to specify a subroutine
-reference to execute when an error occurs in C<get_options()>. For example, the
-following code will replicate the default behavior of C<get_options()>:
-
-    $options->{'error_handler'} = sub {
-        # the Options instance
-        $self = shift;
-        
-        # what caused the error
-        $error_msg = shift;
-        
-        # Do whatever you need to do here, possibly
-        # including calling print_usage()
-        
-        # Returning true would ignore all errors, and attempt
-        # to parse as much as possible, whereas false will
-        # exit immediately with an error code of 1
-        return 0;
-    };
-
-Finally, if you want to do something else with the output of C<print_usage()>,
-you can have it sent to any filehandle object you have kicking around.
-
-For example, if you're on Perl 5.8.6, you can use the StringIO services to
-retrieve a string version of the usage text:
-
-	open(STRINGIO, '+>', \$usage_text) or die $!;
-	$options->{'usage_fh'} = \*STRINGIO;
-	...
-	...
-	...
-	$options->get_options();
-	@usage_lines = <$options->{'usage_fh'}>;
-	
-	# don't forget to close the handle
-	close($options->{'usage_fh'});
-
-
 =head1 AUTHOR
 
 Phil Christensen, E<lt>phil@bubblehouse.orgE<gt>
@@ -455,23 +406,11 @@ sub _pad{
 sub _found_error{
 	my $self = shift;
 	my $reason = shift;
-	
-	my $error_handler = $self->{'error_handler'};
-	my $result;
-	if(defined($error_handler)){
-		$result = $error_handler->($self, $reason);
-	}
-	else{
-		$self->print_usage($reason);
-		$result = 0;
-	}
-	
-	unless($result){
-		if($self->{'exit'}){
-			exit(1);
-		}
-		die($reason);
+	$self->print_usage($reason);
+	if($self->{'exit'}){
+		exit(1);
 	}
+	die($reason);
 }
 
 1;
